Modules and Classes
===================

.. toctree::
   :maxdepth: 1
   :caption: Core:

   _architecture/zntrack
   _architecture/DVCParams
   _architecture/SlurmConfig
   _architecture/descriptors

.. toctree::
   :maxdepth: 1
   :caption: Interface:

   _architecture/interface_base
   _architecture/project
